NKI enhanced surface


Notes
-----
Enhanced Nathan Kline Institute-Rockland Sample resting state fMRI data
(TR=645ms) of 102 subjects, preprocessed and projected to the fsaverage5 surface
according to https://github.com/fliem/nki_nilearn.
Contains phenotypical metadata.

Content
-------
    :'func_left': resting-state data for the left hemisphere
    :'func_right': resting-state data for the right hemisphere
    :'phenotypic': phenotypical metadata


References
----------
:Download: http://fcon_1000.projects.nitrc.org/indi/enhanced/

Nooner et al, (2012). The NKI-Rockland Sample: A model for accelerating the
pace of discovery science in psychiatry. Frontiers in neuroscience 6, 152.
URL http://dx.doi.org/10.3389/fnins.2012.00152
